@@ -6,7 +6,7 @@ class FishList(DAList):
     def init(self, *pargs, **kwargs):
         self.object_type = Fish
         self.complete_attribute = 'fish_complete'
-        super(FishList, self).init(*pargs, **kwargs)
+        super().init(*pargs, **kwargs)
 
 class Fish(DAObject):
     @property
@@ -15,5 +15,5 @@ class Fish(DAObject):
         self.scales
         self.species
     
-    def __unicode__(self):
+    def __str__(self):
         return self.common_name
