@@ -8,7 +8,7 @@ def prog_disclose(template, classname=None):
     else:
         classname = ' ' + classname.strip()
     the_id = re.sub(r'[^A-Za-z0-9]', '', template.instanceName)
-    return u"""\
+    return """\
 <a class="collapsed" data-toggle="collapse" href="#{}" role="button" aria-expanded="false" aria-controls="collapseExample"><span class="pdcaretopen"><i class="fas fa-caret-down"></i></span><span class="pdcaretclosed"><i class="fas fa-caret-right"></i></span> {}</a>
 <div class="collapse" id="{}"><div class="card card-body{} pb-1">{}</div></div>\
 """.format(the_id, template.subject_as_html(trim=True), the_id, classname, template.content_as_html())
